@@ -298,7 +298,9 @@ var SyntheticGestures = (function() {
 
     var c = coordinates(target, x, y);
 
-    touch(target, t || 50, [c.x0, c.x0], [c.y0, c.y0], then);
+    touch(target, t || 50, [c.x0, c.x0], [c.y0, c.y0],  function() {
+      mousetap(target, then, x, y, t, true);
+    });
   }
 
   // Dispatch a dbltap gesture. The arguments are like those to tap()
@@ -431,7 +433,7 @@ var SyntheticGestures = (function() {
   // This is a low-level function that the higher-level mouse gesture
   // utilities are built on. Most testing code will not need to call it.
   //
-  function drag(doc, duration, xt, yt, then, detail, button) {
+  function drag(doc, duration, xt, yt, then, detail, button, sendClick) {
     var win = doc.defaultView;
     detail = detail || 1;
     button = button || 0;
@@ -506,8 +508,12 @@ var SyntheticGestures = (function() {
       // Otherwise, schedule the next move event
       if (last) {
         mouseEvent('mouseup', lastX, lastY);
-        if (then)
+        if (sendClick) {
+          mouseEvent('click', clientX, clientY);
+        }
+        if (then) {
           setTimeout(then, 0);
+        }
       }
       else {
         setTimeout(nextEvent, EVENT_INTERVAL);
@@ -517,14 +523,14 @@ var SyntheticGestures = (function() {
 
   // Send a mousedown/mouseup pair
   // XXX: will the browser automatically follow this with a click event?
-  function mousetap(target, then, x, y, t) {
+  function mousetap(target, then, x, y, t, sendClick) {
     if (x == null)
       x = '50%';
     if (y == null)
       y = '50%';
     var c = coordinates(target, x, y);
 
-    drag(target.ownerDocument, t || 50, [c.x0, c.x0], [c.y0, c.y0], then);
+    drag(target.ownerDocument, t || 50, [c.x0, c.x0], [c.y0, c.y0], then, null, null, sendClick);
   }
 
   // Dispatch a dbltap gesture. The arguments are like those to tap()
